"""
Firebird database expressions for Django.

Custom SQL expressions specific to Firebird.
"""

# Register Firebird-specific expression handlers here
# This file is imported on Django startup via __init__.py
